"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var facebook_common_1 = require("./facebook.common");
var app = require("tns-core-modules/application");
var user_1 = require("./user");
var Facebook = (function (_super) {
    __extends(Facebook, _super);
    function Facebook() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Facebook.prototype.initialize = function () {
        var _this = this;
        var context = app.android.context.getApplicationContext();
        com.facebook.FacebookSdk.setAutoLogAppEventsEnabled(true);
        com.facebook.FacebookSdk.setApplicationId(this.id);
        com.facebook.FacebookSdk.sdkInitialize(context, new com.facebook.FacebookSdk.InitializeCallback({
            onInitialized: this.initializeUser.bind(this)
        }));
        this.manager = com.facebook.login.LoginManager.getInstance();
        this.fields = this.fields;
        var callback = com.facebook.CallbackManager.Factory.create();
        this.manager.registerCallback(callback, this.handleLogin.call(this));
        this.subscribe(callback);
        var trackerForLogout = com.facebook.AccessTokenTracker.extend({
            onCurrentAccessTokenChanged: function (oldToken, newToken) {
                if (oldToken !== null && newToken === null) {
                    _this.logoutCallback();
                }
            }
        });
        new trackerForLogout().startTracking();
    };
    Facebook.prototype.login = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.loginCallback = function (user) { return resolve(user); };
            _this.errorCallback = function (error) { return reject(error); };
            var _a = app.android, startActivity = _a.startActivity, foregroundActivity = _a.foregroundActivity;
            var activity = startActivity || foregroundActivity;
            _this.manager.logInWithReadPermissions(activity, java.util.Arrays.asList(_this.permissions));
        });
    };
    Facebook.prototype.logout = function () {
        var _this = this;
        return new Promise(function (resolve) {
            _this.logoutCallback = function (value) { return resolve(value); };
            _this.manager.logOut();
            _this.logoutCallback();
        });
    };
    Facebook.prototype.handleLogin = function () {
        var _this = this;
        return new com.facebook.FacebookCallback({
            onSuccess: function (data) { return _this.fetchUser(data.getAccessToken()).then(function (user) { return _this.loginCallback(user); }); },
            onError: function (error) { return _this.errorCallback(error); },
            onCancel: function () { return _this.errorCallback('Login cancelled.'); }
        });
    };
    Facebook.prototype.fetchUser = function (token) {
        var _this = this;
        return new Promise(function (resolve) {
            var _a = com.facebook.GraphRequest, GraphJSONObjectCallback = _a.GraphJSONObjectCallback, newMeRequest = _a.newMeRequest;
            var graphJSON = new GraphJSONObjectCallback({
                onCompleted: function (data) { return resolve(new user_1.default(data, 'facebook')); }
            });
            var request = newMeRequest(token, graphJSON);
            var parameters = new android.os.Bundle();
            parameters.putString('fields', _this.fields.join(','));
            request.setParameters(parameters);
            request.executeAsync();
        });
    };
    Facebook.prototype.getCurrentToken = function (toString) {
        if (toString === void 0) { toString = false; }
        return com.facebook.AccessToken.getCurrentAccessToken()
            ? com.facebook.AccessToken.getCurrentAccessToken().getToken()
            : null;
    };
    Facebook.prototype.getCurrentUser = function () {
        var _this = this;
        return new Promise(function (resolve) {
            _this.fetchUser(com.facebook.AccessToken.getCurrentAccessToken()).then(function (user) { return resolve(user); });
        });
    };
    Facebook.prototype.onActivityResult = function (args, callback) {
        var requestCode = args.requestCode, resultCode = args.resultCode, intent = args.intent;
        if (callback.onActivityResult(requestCode, resultCode, intent)) {
            this.unsubscribe(callback);
        }
    };
    Facebook.prototype.unsubscribe = function (callback) {
        var _this = this;
        var activityResultEvent = app.AndroidApplication.activityResultEvent;
        app.android.off(activityResultEvent, function (args) {
            return _this.onActivityResult(args, callback);
        });
    };
    Facebook.prototype.subscribe = function (callback) {
        var _this = this;
        var activityResultEvent = app.AndroidApplication.activityResultEvent;
        app.android.on(activityResultEvent, function (args) {
            return _this.onActivityResult(args, callback);
        });
    };
    return Facebook;
}(facebook_common_1.Facebook));
exports.Facebook = Facebook;
//# sourceMappingURL=facebook.android.js.map